@@ -44,7 +44,7 @@ from google.cloud.functions.context import Context
 from functions_framework._of.v2.context import FunctionContext
 _FUNC_CTX = dict()
 KNATIVE_FUNC = "Knative"
-ASYNC = "async"
+ASYNC = "Async"
 
 MAX_CONTENT_LENGTH = 10 * 1024 * 1024
 
@@ -355,16 +355,22 @@ def _configure_dapr_app(_app, function, ctx: FunctionContext):
     inputs = ctx.inputs
     if inputs is not None:
         for input in inputs.values():
-            if input.type == _DAPR_BINDINGS:
-
-                _app.binding(input.component)(function)
-                print("binding {}".format(input.component))
+            inputTypeList = str(input.componentType).split(".")
+            if len(inputTypeList)>2:
+                raise InvalidFuncContextInputType(
+                    "Invalid input componentType {}".format(input.componentType)
+                )
+            type = inputTypeList[0]
+            component = inputTypeList[1]
+            if type == _DAPR_BINDINGS:
+                _app.binding(input.componentName)(function)
+                print("binding {}".format(input.componentName))
             elif input.type == _DAPR_PUBSUB:
-                _app.subscribe(topic=input.uri, pubsub_name=input.component)(function)
-                print("sub topic {}, pubsub name {}".format(input.uri, input.component))
+                _app.subscribe(topic=input.uri, pubsub_name=input.componentName)(function)
+                print("sub topic {}, pubsub name {}".format(input.uri, input.componentName))
             else:
                 raise InvalidFuncContextInputType(
-                    "Invalid input type {}".format(input.type)
+                    "Invalid input componentType {}".format(input.componentType)
                 )
     else:
         raise MissingOFFunctionInputENV(
